@@ -9,19 +9,15 @@ use JSON;
 # https://specs.opencontainers.org/image-spec/image-index/?v=v1.1.1
 class Container::Builder::Index {
 	method generate_index($manifest_digest, $manifest_size) {
-		my %manifest = (
-			mediaType => 'application/vnd.oci.image.manifest.v1+json',
-			digest => 'sha256:' . $manifest_digest,
-			size => $manifest_size
-		);
-		my @manifests = (\%manifest);
-		my %index = (
-			schemaVersion => 2,
-			manifests => \@manifests
-		);
 		# TODO: you can annotate and pass the container name
-		my $json = encode_json(\%index);
-		return $json;
+		return encode_json({
+			schemaVersion => 2,
+			manifests => [{
+				mediaType => 'application/vnd.oci.image.manifest.v1+json',
+				digest => 'sha256:' . $manifest_digest,
+				size => int($manifest_size)
+			}]
+		});
 	}
 }
 
